summaryrefslogtreecommitdiffstats
path: root/kmail/kmsender.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmsender.cpp')
-rw-r--r--kmail/kmsender.cpp48
1 files changed, 24 insertions, 24 deletions
diff --git a/kmail/kmsender.cpp b/kmail/kmsender.cpp
index 208bf574..1d267d88 100644
--- a/kmail/kmsender.cpp
+++ b/kmail/kmsender.cpp
@@ -80,7 +80,7 @@ KMSender::~KMSender()
void KMSender::seStatusMsg(const TQString &msg)
{
if ( mProgressItem )
- mProgressItem->seStatus(msg);
+ mProgressItem->setqStatus(msg);
}
//-----------------------------------------------------------------------------
@@ -164,7 +164,7 @@ bool KMSender::doSend(KMMessage* aMsg, short sendNow)
KMFolder * const outbox = kmkernel->outboxFolder();
const KMFolderOpener openOutbox( outbox, "outbox" );
- aMsg->seStatus(KMMsgStatusQueued);
+ aMsg->setqStatus(KMMsgStatusQueued);
if ( const int err = outbox->addMsg(aMsg) ) {
Q_UNUSED( err );
@@ -178,7 +178,7 @@ bool KMSender::doSend(KMMessage* aMsg, short sendNow)
* the mail is in a sane state before sending. The unGet makes the
* attached unencrypted version of the mail (if there is one ) disappear.
* though, so we need to make sure to keep it around and restore it
* afterwards. The real fix would be to tqreplace the unGet with
* whatever parsing is triggered by it, but I'm too chicken to do that,
* in this branch.
* Note that the unencrypted mail will be lost if the mail remains in
@@ -293,7 +293,7 @@ void KMSender::doSendMsg()
{
mCurrentMsg->setTransferInProgress( false );
if( mCurrentMsg->hasUnencryptedMsg() ) {
- kdDebug(5006) << "KMSender::doSendMsg() post-processing: tqreplace mCurrentMsg body by unencryptedMsg data" << endl;
+ kdDebug(5006) << "KMSender::doSendMsg() post-processing: replace mCurrentMsg body by unencryptedMsg data" << endl;
// delete all current body parts
mCurrentMsg->deleteBodyParts();
// copy Content-[..] headers from unencrypted message to current one
@@ -314,8 +314,8 @@ void KMSender::doSendMsg()
mCurrentMsg->addBodyPart( &msgPart );
}
}
- mCurrentMsg->seStatus(KMMsgStatusSent);
- mCurrentMsg->seStatus(KMMsgStatusRead); // otherwise it defaults to new on imap
+ mCurrentMsg->setqStatus(KMMsgStatusSent);
+ mCurrentMsg->setqStatus(KMMsgStatusRead); // otherwise it defaults to new on imap
mCurrentMsg->updateAttachmentState();
mCurrentMsg->updateInvitationState();
@@ -363,9 +363,9 @@ void KMSender::doSendMsg()
// Disable the emitting of msgAdded signal, because the message is taken out of the
// current folder (outbox) and re-added, to make filter actions changing the message
// work. We don't want that to screw up message counts.
- if ( mCurrentMsg->parent() ) mCurrentMsg->parent()->quiet( true );
+ if ( mCurrentMsg->tqparent() ) mCurrentMsg->tqparent()->quiet( true );
const int processResult = kmkernel->filterMgr()->process(mCurrentMsg,KMFilterMgr::Outbound);
- if ( mCurrentMsg->parent() ) mCurrentMsg->parent()->quiet( false );
+ if ( mCurrentMsg->tqparent() ) mCurrentMsg->tqparent()->quiet( false );
// 0==processed ok, 1==no filter matched, 2==critical error, abort!
switch (processResult) {
@@ -401,13 +401,13 @@ void KMSender::doSendMsg()
break;
}
seStatusByLink( mCurrentMsg );
- if (mCurrentMsg->parent() && !imapSentFolder) {
+ if (mCurrentMsg->tqparent() && !imapSentFolder) {
// for speed optimization, this code assumes that mCurrentMsg is the
- // last one in it's parent folder; make sure that's really the case:
- assert( mCurrentMsg->parent()->find( mCurrentMsg )
- == mCurrentMsg->parent()->count() - 1 );
+ // last one in it's tqparent folder; make sure that's really the case:
+ assert( mCurrentMsg->tqparent()->tqfind( mCurrentMsg )
+ == mCurrentMsg->tqparent()->count() - 1 );
// unGet this message:
- mCurrentMsg->parent()->unGetMsg( mCurrentMsg->parent()->count() -1 );
+ mCurrentMsg->tqparent()->unGetMsg( mCurrentMsg->tqparent()->count() -1 );
}
mCurrentMsg = 0;
@@ -710,7 +710,7 @@ void KMSender::slotIdle()
mFailedMessages++;
// reset cached password
TQMapIterator <TQString,TQString> pc;
- if ( (pc = mPasswdCache.find( mMethodStr )) != mPasswdCache.end() ) {
+ if ( (pc = mPasswdCache.tqfind( mMethodStr )) != mPasswdCache.end() ) {
mPasswdCache.erase(pc);
}
// Sending of message failed.
@@ -788,7 +788,7 @@ void KMSender::setSendQuotedPrintable(bool aSendQuotedPrintable)
//-----------------------------------------------------------------------------
KMSendProc* KMSender::createSendProcFromString( const TQString & transport )
{
- mTransportInfo->type = TQString::null;
+ mTransportInfo->type = TQString();
int nr = KMTransportInfo::findTransport(transport);
if (nr)
{
@@ -800,7 +800,7 @@ KMSendProc* KMSender::createSendProcFromString( const TQString & transport )
mTransportInfo->auth = false;
mTransportInfo->encryption = "NONE";
TQString serverport = transport.mid(7);
- int colon = serverport.find(':');
+ int colon = serverport.tqfind(':');
if (colon != -1) {
mTransportInfo->host = serverport.left(colon);
mTransportInfo->port = serverport.mid(colon + 1);
@@ -815,7 +815,7 @@ KMSendProc* KMSender::createSendProcFromString( const TQString & transport )
mTransportInfo->auth = false;
mTransportInfo->encryption = "ssl";
TQString serverport = transport.mid(7);
- int colon = serverport.find(':');
+ int colon = serverport.tqfind(':');
if (colon != -1) {
mTransportInfo->host = serverport.left(colon);
mTransportInfo->port = serverport.mid(colon + 1);
@@ -850,7 +850,7 @@ void KMSender::seStatusByLink(const KMMessage *aMsg)
int n = 0;
while (1) {
ulong msn;
- KMMsgStatus status;
+ KMMsgtqStatus status;
aMsg->getLink(n, &msn, &status);
if (!msn || !status)
break;
@@ -867,7 +867,7 @@ void KMSender::seStatusByLink(const KMMessage *aMsg)
new KMDeleteMsgCommand( folder, folder->getMsg( index ) );
cmd->start();
} else {
- folder->seStatus(index, status);
+ folder->setqStatus(index, status);
}
} else {
kdWarning(5006) << k_funcinfo << "Cannot update linked message, it could not be found!" << endl;
@@ -891,7 +891,7 @@ void KMSendProc::reset()
{
mSending = false;
mSendOk = false;
- mLastErrorMessage = TQString::null;
+ mLastErrorMessage = TQString();
}
//-----------------------------------------------------------------------------
@@ -1082,8 +1082,8 @@ bool KMSendSMTP::doSend( const TQString & sender, const TQStringList & to, const
if (ti->auth)
{
- TQMapIterator<TQString,TQString> tpc = mSender->mPasswdCache.find( ti->name );
- TQString tpwd = ( tpc != mSender->mPasswdCache.end() )?(*tpc):TQString::null;
+ TQMapIterator<TQString,TQString> tpc = mSender->mPasswdCache.tqfind( ti->name );
+ TQString tpwd = ( tpc != mSender->mPasswdCache.end() )?(*tpc):TQString();
if ( ti->passwd().isEmpty() )
ti->setPasswd( tpwd );
@@ -1098,7 +1098,7 @@ bool KMSendSMTP::doSend( const TQString & sender, const TQStringList & to, const
TQString passwd = ti->passwd();
result = KIO::PasswordDialog::getNameAndPassword(ti->user, passwd,
&b, i18n("You need to supply a username and a password to use this "
- "SMTP server."), false, TQString::null, ti->name, TQString::null);
+ "SMTP server."), false, TQString(), ti->name, TQString());
if ( result != TQDialog::Accepted )
{
@@ -1188,7 +1188,7 @@ void KMSendSMTP::doFinish() {
void KMSendSMTP::dataReq(KIO::Job *, TQByteArray &array)
{
// Send it by 32K chuncks
- const int chunkSize = QMIN( mMessageLength - mMessageOffset, 32*1024 );
+ const int chunkSize = TQMIN( mMessageLength - mMessageOffset, 32*1024 );
if ( chunkSize > 0 ) {
array.duplicate(mMessage.data() + mMessageOffset, chunkSize);
mMessageOffset += chunkSize;
@@ -178,7 +178,7 @@ bool KMSender::doSend(KMMessage* aMsg, short sendNow)
* attached unencrypted version of the mail (if there is one ) disappear.
* though, so we need to make sure to keep it around and restore it
- * afterwards. The real fix would be to tqreplace the unGet with
+ * afterwards. The real fix would be to replace the unGet with
* whatever parsing is triggered by it, but I'm too chicken to do that,
* in this branch.